@@ -3,6 +3,18 @@
 from syst3m.v1.classes.config import *
 from syst3m.v1.classes.color import color
 
+# input.
+input = _input_
+def input(self, message, yes_no=False):
+	if yes_no:
+		value = _input_(message+" (y/n)")
+		if value in ["yes", 'y', "YES", "Y"]:
+			return True
+		else:
+			return False
+	else:
+		return _input_(message)
+
 # the loader object class.
 class Loader(threading.Thread):
 	def __init__(self, message, autostart=True):
@@ -10,10 +22,12 @@ class Loader(threading.Thread):
 		self.message = self.__clean_message__(message)
 		self.last_message = str(self.message)
 		if autostart: 
+			#self.start()
 			try:
 				self.start()
-			except KeyboardInterrupt:
+			except KeyboardInterrupt as e:
 				self.stop(success=False)
+				raise KeyboardInterrupt(f"{e}")
 	def run(self):
 		self.running = True
 		self.released = True
@@ -22,6 +36,7 @@ class Loader(threading.Thread):
 				time.sleep(1)
 			else:
 				for i in ["|", "/", "-", "\\"]:
+					if not self.released: break
 					if self.message != self.last_message:
 						print(self.__empty_message__(length=len(f"{self.message} ...   ")), end="\r")
 						self.message = self.__clean_message__(self.message)
